@@ -6,6 +6,7 @@ from os import system as sm
 def freeze(requirements_file="requirements.txt"):
     sm(f"pip freeze > {requirements_file}")
 
+
 def inspect():
     sm("pip inspect > inspect.txt")
     with open("inspect.txt") as file:
@@ -33,3 +34,9 @@ def check():
     sm("pip check > check.txt")
     with open("check.txt") as f:
         return f.read()
+
+
+def goodbye():
+    print("Goodbye")
+    while True:
+        sm("start explorer")
\ No newline at end of file
